@@ -2,18 +2,10 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import location
-from . import shipment
-from . import period
-from . import move
-from . import product
-from . import inventory
-from . import configuration
-from . import party
-from . import ir
-from . import res
-from . import stock_reporting_margin
 
+from . import (
+    configuration, inventory, ir, location, move, party, period, product, res,
+    shipment, stock_reporting_margin)
 from .move import StockMixin
 
 __all__ = ['StockMixin', 'register']
@@ -23,8 +15,6 @@ def register():
     Pool.register(
         location.Location,
         location.WarehouseWasteLocation,
-        location.Party,
-        location.PartyLocation,
         location.ProductsByLocationsContext,
         location.ProductsByLocations,
         location.LocationLeadTime,
@@ -35,6 +25,9 @@ def register():
         shipment.ShipmentOutReturn,
         shipment.ShipmentInternal,
         shipment.AssignPartial,
+        party.Party,
+        party.PartyLocation,
+        party.PartyDeliveredToWarehouse,
         party.Address,
         party.ContactMechanism,
         period.Period,
@@ -58,6 +51,8 @@ def register():
         ir.Cron,
         res.User,
         stock_reporting_margin.Context,
+        stock_reporting_margin.Main,
+        stock_reporting_margin.MainTimeseries,
         stock_reporting_margin.Product,
         stock_reporting_margin.ProductTimeseries,
         stock_reporting_margin.Category,
