@@ -1,13 +1,11 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond import backend
-from trytond.model import (ModelView, ModelSQL, ModelSingleton, ValueMixin,
-    fields)
-from trytond.pool import Pool
-from trytond.pyson import Eval, Id
-from trytond.tools.multivalue import migrate_property
+from trytond.model import (
+    ModelSingleton, ModelSQL, ModelView, ValueMixin, fields)
 from trytond.modules.company.model import (
     CompanyMultiValueMixin, CompanyValueMixin)
+from trytond.pool import Pool
+from trytond.pyson import Eval, Id
 
 sequences = ['shipment_in_sequence', 'shipment_in_return_sequence',
     'shipment_out_sequence', 'shipment_out_return_sequence',
@@ -16,6 +14,7 @@ shipment_internal_transit = fields.Many2One(
     'stock.location', "Internal Shipment Transit", required=True,
     domain=[
         ('type', '=', 'storage'),
+        ('parent', '=', None),
         ],
     help="The default location used for stock that is in transit between "
     "warehouses.")
@@ -137,66 +136,42 @@ class ConfigurationSequence(ModelSQL, CompanyValueMixin):
             ('company', 'in', [Eval('company', -1), None]),
             ('sequence_type', '=',
                 Id('stock', 'sequence_type_shipment_in')),
-            ],
-        depends=['company'])
+            ])
     shipment_in_return_sequence = fields.Many2One(
         'ir.sequence', "Supplier Return Shipment Sequence", required=True,
         domain=[
             ('company', 'in', [Eval('company', -1), None]),
             ('sequence_type', '=',
                 Id('stock', 'sequence_type_shipment_in_return')),
-            ],
-        depends=['company'])
+            ])
     shipment_out_sequence = fields.Many2One(
         'ir.sequence', "Customer Shipment Sequence", required=True,
         domain=[
             ('company', 'in', [Eval('company', -1), None]),
             ('sequence_type', '=',
                 Id('stock', 'sequence_type_shipment_out')),
-            ],
-        depends=['company'])
+            ])
     shipment_out_return_sequence = fields.Many2One(
         'ir.sequence', "Customer Return Shipment Sequence", required=True,
         domain=[
             ('company', 'in', [Eval('company', -1), None]),
             ('sequence_type', '=',
                 Id('stock', 'sequence_type_shipment_out_return')),
-            ],
-        depends=['company'])
+            ])
     shipment_internal_sequence = fields.Many2One(
         'ir.sequence', "Internal Shipment Sequence", required=True,
         domain=[
             ('company', 'in', [Eval('company', -1), None]),
             ('sequence_type', '=',
                 Id('stock', 'sequence_type_shipment_internal')),
-            ],
-        depends=['company'])
+            ])
     inventory_sequence = fields.Many2One(
         'ir.sequence', "Inventory Sequence", required=True,
         domain=[
             ('company', 'in', [Eval('company', -1), None]),
             ('sequence_type', '=',
                 Id('stock', 'sequence_type_inventory')),
-            ],
-        depends=['company'])
-
-    @classmethod
-    def __register__(cls, module_name):
-        exist = backend.TableHandler.table_exist(cls._table)
-
-        super(ConfigurationSequence, cls).__register__(module_name)
-
-        if not exist:
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        field_names.extend(sequences)
-        value_names.extend(sequences)
-        fields.append('company')
-        migrate_property(
-            'stock.configuration', field_names, cls, value_names,
-            fields=fields)
+            ])
 
     default_shipment_in_sequence = default_sequence('sequence_shipment_in')
     default_shipment_in_return_sequence = default_sequence(
@@ -214,23 +189,6 @@ class ConfigurationLocation(ModelSQL, ValueMixin):
     __name__ = 'stock.configuration.location'
     shipment_internal_transit = shipment_internal_transit
 
-    @classmethod
-    def __register__(cls, module_name):
-        exist = backend.TableHandler.table_exist(cls._table)
-
-        super(ConfigurationLocation, cls).__register__(module_name)
-
-        if not exist:
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        field_names.append('shipment_internal_transit')
-        value_names.append('shipment_internal_transit')
-        migrate_property(
-            'stock.configuration', field_names, cls, value_names,
-            fields=fields)
-
     @classmethod
     def default_shipment_internal_transit(cls):
         pool = Pool()
