@@ -42,3 +42,11 @@ class InventoryFutureWarning(UserWarning):
 
 class ProductCostPriceError(ValidationError):
     pass
+
+
+class ProductStockWarning(UserWarning):
+    pass
+
+
+class ShipmentCheckQuantityWarning(UserWarning):
+    pass
