@@ -127,16 +127,17 @@ class Period(Workflow, ModelSQL, ModelView):
             if recent_date >= today:
                 raise PeriodCloseError(
                     gettext('stock.msg_period_close_date'))
-        if Move.search([
-                    ('state', '=', 'assigned'),
-                    ['OR', [
-                            ('effective_date', '=', None),
-                            ('planned_date', '<=', recent_date),
-                            ],
-                        ('effective_date', '<=', recent_date),
-                        ]]):
-            raise PeriodCloseError(
-                gettext('stock.msg_period_close_assigned_move'))
+            if Move.search([
+                        ('company', '=', company.id),
+                        ('state', '=', 'assigned'),
+                        ['OR', [
+                                ('effective_date', '=', None),
+                                ('planned_date', '<=', recent_date),
+                                ],
+                            ('effective_date', '<=', recent_date),
+                            ]]):
+                raise PeriodCloseError(
+                    gettext('stock.msg_period_close_assigned_move'))
 
         for grouping in cls.groupings():
             Cache = cls.get_cache(grouping)
